changeset 569:000b675e7c1d

bumped version, some spelling fixes
author Marcin Kuzminski <marcin@python-works.com>
date Sun, 10 Oct 2010 17:27:46 +0200
parents 5f481e4e888b
children 31c8965cfad8
files rhodecode/__init__.py rhodecode/lib/db_manage.py rhodecode/lib/utils.py rhodecode/model/hg_model.py rhodecode/templates/base/base.html rhodecode/templates/files/file_diff.html
diffstat 6 files changed, 11 insertions(+), 11 deletions(-) [+]
line wrap: on
line diff
--- a/rhodecode/lib/db_manage.py	Sun Oct 10 17:24:41 2010 +0200
+++ b/rhodecode/lib/db_manage.py	Sun Oct 10 17:27:46 2010 +0200
@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # encoding: utf-8
-# database managment for hg app
+# database management for RhodeCode
 # Copyright (C) 2009-2010 Marcin Kuzminski <marcin@python-works.com>
 #
 # This program is free software; you can redistribute it and/or
@@ -20,7 +20,7 @@
 
 """
 Created on April 10, 2010
-database managment and creation for hg app
+database management and creation for RhodeCode
 @author: marcink
 """
 
--- a/rhodecode/lib/utils.py	Sun Oct 10 17:24:41 2010 +0200
+++ b/rhodecode/lib/utils.py	Sun Oct 10 17:27:46 2010 +0200
@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # encoding: utf-8
-# Utilities for hg app
+# Utilities for RhodeCode
 # Copyright (C) 2009-2010 Marcin Kuzminski <marcin@python-works.com>
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -19,7 +19,7 @@
 
 """
 Created on April 18, 2010
-Utilities for hg app
+Utilities for RhodeCode
 @author: marcink
 """
 from beaker.cache import cache_region
--- a/rhodecode/model/hg_model.py	Sun Oct 10 17:24:41 2010 +0200
+++ b/rhodecode/model/hg_model.py	Sun Oct 10 17:27:46 2010 +0200
@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # encoding: utf-8
-# Model for hg app
+# Model for RhodeCode
 # Copyright (C) 2009-2010 Marcin Kuzminski <marcin@python-works.com>
 # 
 # This program is free software; you can redistribute it and/or
@@ -19,7 +19,7 @@
 # MA  02110-1301, USA.
 """
 Created on April 9, 2010
-Model for hg app
+Model for RhodeCode
 @author: marcink
 """
 from beaker.cache import cache_region
--- a/rhodecode/templates/base/base.html	Sun Oct 10 17:24:41 2010 +0200
+++ b/rhodecode/templates/base/base.html	Sun Oct 10 17:27:46 2010 +0200
@@ -66,7 +66,7 @@
 
 	<!-- footer -->
 	<div id="footer">
-	    <p>Hg App ${c.rhodecode_version} &copy; 2010 by Marcin Kuzminski</p>
+	    <p>RhodeCode ${c.rhodecode_version} &copy; 2010 by Marcin Kuzminski</p>
         <script type="text/javascript">${h.tooltip.activate()}</script>	    
 	</div>
 	<!-- end footer -->
--- a/rhodecode/templates/files/file_diff.html	Sun Oct 10 17:24:41 2010 +0200
+++ b/rhodecode/templates/files/file_diff.html	Sun Oct 10 17:27:46 2010 +0200
@@ -1,7 +1,7 @@
 <%inherit file="/base/base.html"/>
 
 <%def name="title()">
-    ${_('Repository managment')}
+    ${_('Repository management')}
 </%def>
 <%def name="breadcrumbs_links()">
     ${h.link_to(u'Home',h.url('/'))}
--- a/rhodecode/__init__.py	Sun Oct 10 17:24:41 2010 +0200
+++ b/rhodecode/__init__.py	Sun Oct 10 17:27:46 2010 +0200
@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # encoding: utf-8
 # Hg app, a web based mercurial repository managment based on pylons
 # Copyright (C) 2009-2010 Marcin Kuzminski <marcin@python-works.com>
 # 
 # This program is free software; you can redistribute it and/or
@@ -19,12 +19,12 @@
 # MA  02110-1301, USA.
 """
 Created on April 9, 2010
-Hg app, a web based mercurial repository managment based on pylons
+RhodeCode, a web based repository management based on pylons
 versioning implementation: http://semver.org/
 @author: marcink
 """
 
-VERSION = (0, 8, 5, 'beta')
+VERSION = (1, 0, 0, 'rc1')
 
 __version__ = '.'.join((str(each) for each in VERSION[:4]))
 
@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # encoding: utf-8
-# Hg app, a web based mercurial repository managment based on pylons
+# RhodeCode, a web based repository management based on pylons
 # Copyright (C) 2009-2010 Marcin Kuzminski <marcin@python-works.com>
 # 